ExpMetFilter: ExpMetFilter

Description Usage Arguments Value

View source: R/ExpMetFilter.R

Description

A series of filters which removes a large subset of peaks from non-targeted analysis based on user input Specifically focused on removing exposure compounds and their metabolites from toxicological experiments

Usage

1
ExpMetFilter(File = NULL, report = FALSE)

Arguments

File

The path to, including the name and file-ending of, where the result file should be created

report

When set to 'True' will output a PDF file with how many features were removed due to each filtering process

Value

Outputs a result file with all the peaks and sample split into whether they were filtered out or not


parasitetwin/ExpMetFilter documentation built on Nov. 4, 2019, 11:18 p.m.